@@ -1,5 +1,5 @@
 /*#####################################################*/
-/*##           drivemount applet 0.1.0 alpha         ##*/
+/*##           drivemount applet 0.1.1 beta          ##*/
 /*#####################################################*/
 
 #include "drivemount.h"
@@ -24,7 +24,7 @@
 static void about_cb (AppletWidget *widget, gpointer data)
 {
 	GtkWidget *about;
-	gchar *authors[2];
+	const gchar *authors[2];
 	gchar version[32];
 
 	sprintf(version,"%d.%d.%d",DRIVEMOUNT_APPLET_VERSION_MAJ,
@@ -121,6 +121,61 @@ static int mount_cb(GtkWidget *widget, gpointer data)
 	return FALSE;
 }
 
+static void eject_cb(AppletWidget *applet, gpointer data)
+{
+	DriveData *dd = data;
+	char command_line[300];
+	char buffer[200];
+	char dn[100];	/* Devicename */
+	char mp[100];	/* Mountpoint */
+	FILE *ml;	/* Mountlist */
+
+
+	/*
+	 * Search the output of mount for dd->mount_point
+	 * and use the corresponting device name
+	 * as argument for eject
+	 * if the device is not mounted currently, use
+	 * /etc/fstab for the check
+	 */
+	
+	if (dd->mounted) {
+		ml = popen("mount", "r");
+		while (fgets(buffer, 200, ml)) {
+			sscanf(buffer, "%s %*s %s", dn, mp);
+			if (!strcmp(mp, dd->mount_point))
+				break;
+		}
+		pclose (ml);
+	} else {
+		ml = fopen("/etc/fstab", "r");
+		while (fgets(buffer, 200, ml)) {
+			sscanf(buffer, "%s %s", dn, mp);
+			if (!strcmp(mp, dd->mount_point))
+				break;
+		}
+		fclose (ml);
+	}
+	
+	if (strcmp(mp, dd->mount_point)) {	/* mp != dd->mount_point */
+		printf("WARNING: drivemount.c ... dd->mount_point not found in list\
+			 (output of mount, or /etc/fstab) \n");
+		return;
+	}
+
+	if (dd->mounted)
+		sprintf (command_line, "eject -u %s", dn);
+	else	
+		sprintf (command_line, "eject %s", dn);
+
+	system (command_line);
+
+	
+	return;
+
+}	
+
+
 /* start or change the update callback timeout interval */
 void start_callback_update(DriveData *dd)
 {
@@ -232,10 +287,10 @@ static void applet_change_orient(GtkWidget *w, PanelOrientType o, gpointer data)
 	redraw_pixmap(dd);
 }
 
-static gint applet_session_save(GtkWidget *widget, char *cfgpath, char *globcfgpath, gpointer data)
+static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath, gpointer data)
 {
 	DriveData *dd = data;
-	property_save(cfgpath, dd);
+	property_save(privcfgpath, dd);
         return FALSE;
 }
 
@@ -252,7 +307,7 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	dd->propwindow = NULL;
 	dd->mount_base = strdup("/mnt");
 
-	property_load(APPLET_WIDGET(applet)->cfgpath, dd);
+	property_load(APPLET_WIDGET(applet)->privcfgpath, dd);
 
 	dd->button=gtk_button_new();
 	gtk_signal_connect(GTK_OBJECT(dd->button),"clicked",
@@ -275,18 +330,28 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
 				GTK_SIGNAL_FUNC(applet_change_orient),
 				dd);
-	gtk_signal_connect(GTK_OBJECT(applet),"session_save",
-				GTK_SIGNAL_FUNC(applet_session_save),
+	gtk_signal_connect(GTK_OBJECT(applet),"save_session",
+				GTK_SIGNAL_FUNC(applet_save_session),
 				dd);
-	applet_widget_register_callback(APPLET_WIDGET(applet),
-					"properties",
-					_("Properties..."),
-					property_show,
-					dd);
-	applet_widget_register_callback(APPLET_WIDGET(applet),
-					"about",
-					_("About..."),
-					about_cb, NULL);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "properties",
+					      GNOME_STOCK_MENU_PROP,
+					      _("Properties..."),
+					      property_show,
+					      dd);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "about",
+					      GNOME_STOCK_MENU_ABOUT,
+					      _("About..."),
+					      about_cb, NULL);
+
+	/* add "eject" entry if eject program is found in PATH */
+	if (gnome_is_program_in_path("eject"))
+		applet_widget_register_callback(APPLET_WIDGET(applet),
+					      "eject",
+					      _("Eject"),
+					      eject_cb,
+					      dd);
 
 	start_callback_update(dd);
 	return dd;
