@@ -2,28 +2,19 @@
 #define GNOME_DESKTOP_H
 
 #include <gnome.h>
-#include <libgnomeui/gnome-properties.h>
 
 BEGIN_GNOME_DECLS
 
-void register_extension (GtkWidget *title_widget, GtkWidget *content_widget,
-			 int (*callback)(GnomePropertyRequest));
-
-#define GNOME_PAD 10
-
-/* Keep these in sync with the monitor image */
-
-#define MONITOR_CONTENTS_X 20
-#define MONITOR_CONTENTS_Y 10
-#define MONITOR_CONTENTS_WIDTH 157
-#define MONITOR_CONTENTS_HEIGHT 111
-
-GtkWidget *get_monitor_preview_widget (void);
+extern GtkWidget *main_window;
 
 /* A property sheet should call this function when the user has made
    a change that could be applied.  */
 void property_changed (void);
 
+/* A property sheet should call this function when the user has
+   clicked on the apply button. */
+void property_applied (void);
+
 /* This is what an application's main() should call.  It isn't named
    main() since that doesn't always work well in libraries.  */
 int property_main (char *app_id, int argc, char *argv[]);
@@ -43,6 +34,13 @@ char *application_title (void);
    mutex.  */
 char *application_property (void);
 
+extern int init;
+
+extern int need_sync;
+
+/* Options used by this program.  */
+extern struct argp parser;
+
 END_GNOME_DECLS
 
 #endif
