@@ -1,65 +1,70 @@
 /*###################################################################*/
-/*##                       gmenu (GNOME menu editor) 0.2.5         ##*/
+/*##                       gmenu (GNOME menu editor) 0.3.0         ##*/
 /*###################################################################*/
 
 #include <config.h>
 
 #include "gmenu.h"
+#include "wait-feet.h"
 #include "top.xpm"
 
+static gint find_file_cb(gconstpointer a, gconstpointer b);
 static void move_item_down(GtkCTreeNode *node);
 static void move_item_up(GtkCTreeNode *node);
 static void add_tree_recurse_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data);
+static void get_ctree_count_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data);
+static gint get_ctree_count(GtkCTree *ctree);
 
-/* if ctree = null, reset ret. if node = null, return ret. */
-static GtkCTreeNode *check_file_match(GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
+/* new = TRUE, increment feet = FALSE */
+static GtkWidget *wait_pixmap(gint mode)
 {
-	static GtkCTreeNode *ret = NULL;
-	char *path = data;
-	Desktop_Data *d;
+	static GtkWidget *p;
 
-	if (!ctree)
-		{
-		ret = NULL;
-		return ret;
-		}
+	static gint c;
 
-	if (!node)
+	if (mode)
 		{
-		return ret;
-		}
-
-	d = gtk_ctree_get_row_data(GTK_CTREE(ctree), node);
-	if (d->path && !strcmp(d->path, path))
-		{
-		ret = node;
-		return ret;
+		c = 0;
+		p = gnome_pixmap_new_from_xpm_d(wait_1_xpm);
+		return p;
 		}
 	else
+		{
+		c++;
+		if (c > 7) c = 0;
+
+		if (c == 0) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_1_xpm);
+		if (c == 1) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_2_xpm);
+		if (c == 2) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_3_xpm);
+		if (c == 3) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_4_xpm);
+		if (c == 4) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_5_xpm);
+		if (c == 5) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_6_xpm);
+		if (c == 6) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_7_xpm);
+		if (c == 7) gnome_pixmap_load_xpm_d(GNOME_PIXMAP(p),wait_8_xpm);
+
+		gtk_widget_draw(p, NULL);
+
 		return NULL;
+		}
+}
+
+static gint find_file_cb(gconstpointer a, gconstpointer b)
+{
+	if (!((Desktop_Data *)(a))->path) return 1;
+
+	return strcmp(((Desktop_Data *)(a))->path, (gchar *)b);
 }
 
 GtkCTreeNode *find_file_in_tree(GtkCTree * ctree, char *path)
 {
-	GtkCTreeNode *node = NULL;
-
-	/* reset the static pointer */
-	check_file_match(NULL, NULL, NULL);
-
-	/* do the check */
-	gtk_ctree_pre_recursive(GTK_CTREE(ctree), NULL, (GtkCTreeFunc) check_file_match, path);
-
-	/* get the static pointer */
-	node = check_file_match(ctree, NULL, NULL);
-
-	return node;
+	return gtk_ctree_find_by_row_data_custom (GTK_CTREE(ctree), NULL, path, find_file_cb);
 }
 
 void update_tree_highlight(GtkWidget *w, GtkCTreeNode *old, GtkCTreeNode *new, gint select)
 {
 	Desktop_Data *d;
 
-        if (old) gtk_ctree_unselect(GTK_CTREE(w),old);
+	if (old) gtk_ctree_unselect(GTK_CTREE(w),old);
         if (new && select) gtk_ctree_select(GTK_CTREE(w),new);
 
 	d = gtk_ctree_get_row_data(GTK_CTREE(w), new);
@@ -81,9 +86,6 @@ void update_tree_highlight(GtkWidget *w, GtkCTreeNode *old, GtkCTreeNode *new, g
 		}
 	gtk_label_set(GTK_LABEL(pathlabel),current_path);
 
-/*	if (move)
-		gtk_ctree_moveto (GTK_CTREE(w), new, 0, 0.5, 0.0);
-*/
 }
 
 static void move_item_down(GtkCTreeNode *node)
@@ -153,13 +155,10 @@ int is_node_editable(GtkCTreeNode *node)
 	gtk_ctree_get_node_info(GTK_CTREE(menu_tree_ctree),node,
 		NULL,NULL,NULL,NULL,NULL,NULL,&leaf,NULL);
 	if (leaf)
-		{
 		parent = GTK_CTREE_ROW(node)->parent;
-		}
 	else
-		{
 		parent = node;
-		}
+
 	d = gtk_ctree_get_row_data(GTK_CTREE(menu_tree_ctree), parent);
 	return d->editable;
 }
@@ -174,30 +173,39 @@ void edit_pressed_cb()
 	update_edit_area(d);
 }
 
-void tree_item_selected (GtkWidget *widget, gint row, gint column, GdkEventButton *bevent)
+void tree_item_selected (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 {
+	gint row, col;
 	Desktop_Data *d;
-	GtkCTree *ctree = GTK_CTREE(widget);
 	GtkCTreeNode *node;
 
+	if (event->window != GTK_CLIST(ctree)->clist_window) return;
+	if (gtk_ctree_is_hot_spot(ctree, event->x, event->y)) return;
+	if (event->button != 1 && event->button != 3) return;
+
+	gtk_clist_get_selection_info (GTK_CLIST (ctree), event->x, event->y, &row, &col);
+
 	node = GTK_CTREE_NODE(g_list_nth (GTK_CLIST (ctree)->row_list, row));
 
 	if (!node) return;
 
-	if (node == topnode) return;
+	if (node == topnode)
+		{
+		update_tree_highlight(menu_tree_ctree, node, current_node, TRUE);
+		return;
+		}
+
+	if (event->button == 3 && (node == systemnode || node == usernode)) return;
 
 	d = gtk_ctree_get_row_data(GTK_CTREE(ctree),node);
 
-	update_tree_highlight(menu_tree_ctree, current_node, node, FALSE);
+	update_tree_highlight(menu_tree_ctree, current_node, node, TRUE);
 
 	current_node = node;
 
 	if (node == systemnode || node == usernode) return;
 
-	if ( bevent->type == GDK_2BUTTON_PRESS || bevent->button == 2 )
-		{
-		update_edit_area(d);
-		}
+	if (event->button == 3)	update_edit_area(d);
 
 	if (d->isfolder)
 		{
@@ -208,6 +216,7 @@ void tree_item_selected (GtkWidget *widget, gint row, gint column, GdkEventButto
 			}
 		}
 
+	return;
 }
 
 /* if node is null it is appended, if it is a sibling, it is inserted */
@@ -332,17 +341,56 @@ void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent)
 static void add_tree_recurse_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
 {
 	Desktop_Data *d = gtk_ctree_get_row_data(GTK_CTREE(ctree), node);
-	if (d->isfolder && !d->expanded ) add_tree_node(ctree, node);
+	if (d->isfolder && !d->expanded )
+		{
+		wait_pixmap(FALSE);
+		add_tree_node(ctree, node);
+		}
 }
 
+static void get_ctree_count_cb(GtkCTree *ctree, GtkCTreeNode *node, gpointer data)
+{
+	gint *p = data;
+	*p = *p + 1;
+}
+
+static gint get_ctree_count(GtkCTree *ctree)
+{
+	gint count = 0;
+	gtk_ctree_post_recursive (ctree, NULL, get_ctree_count_cb, &count);
+	return count;
+}
 
 void add_main_tree_node()
 {
 	gchar *text[2];
 	Desktop_Data *d;
 	GtkWidget *pixmap;
+	GtkWidget *wait_icon;
+	GtkWidget *dialog;
+	GtkWidget *label;
+	GtkWidget *hbox;
 	gint c;
 
+
+	dialog = gnome_dialog_new(_("GNOME menu editor"),NULL);
+
+	hbox = gtk_hbox_new(FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 5);
+	gtk_widget_show(hbox);
+
+	wait_icon = wait_pixmap(TRUE);
+	gtk_box_pack_start(GTK_BOX(hbox), wait_icon, TRUE, TRUE, 5);
+	gtk_widget_show(wait_icon);
+
+	label = gtk_label_new(_("One moment, reading menus..."));
+	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 5);
+	gtk_widget_show(label);
+
+	gtk_widget_show(dialog);
+
+	while(gtk_events_pending()) gtk_main_iteration();
+
 /*	g_print("adding top node...\n");*/
 
 	gtk_clist_freeze(GTK_CLIST(menu_tree_ctree));
@@ -381,15 +429,11 @@ void add_main_tree_node()
 	d->comment = strdup(_("Top of system menus"));
 	d->expanded = FALSE;
 
-	/* FIXME: are we root? then we can edit the system menu */
-/*
-	if (!strcmp("/root",getenv("HOME")) || 
-	    ((getenv("USER"))&&(!strcmp("root",getenv("USER")))) ||
-		((getenv("USERNAME"))&&(!strcmp("root",getenv("USERNAME")))) )
-*/
+	/* check if the user has permission to edit the system menu */
+
 	if (!access (SYSTEM_APPS, W_OK))
 		{
-		g_print(_("Running with root privileges.\n"));
+		g_print(_("Running with System Menu privileges.\n"));
 		d->editable = TRUE;
 		}
 	else
@@ -416,14 +460,17 @@ void add_main_tree_node()
 
 	/* now load the entire menu tree */
 	c = 0;
-	while (g_list_length((GList *)topnode) > c)
+	while (get_ctree_count(GTK_CTREE(menu_tree_ctree)) > c)
 		{
-		c = g_list_length((GList *)topnode);
-		gtk_ctree_pre_recursive(GTK_CTREE(menu_tree_ctree), topnode, add_tree_recurse_cb, NULL);
+		c = get_ctree_count(GTK_CTREE(menu_tree_ctree));
+
+		gtk_ctree_post_recursive(GTK_CTREE(menu_tree_ctree), topnode, add_tree_recurse_cb, NULL);
 		}
 
 	current_node = usernode;
 
+	gnome_dialog_close(GNOME_DIALOG(dialog));
+
 	gtk_clist_thaw(GTK_CLIST(menu_tree_ctree));
 
 	update_tree_highlight(menu_tree_ctree, NULL, current_node, FALSE);
