@@ -22,8 +22,10 @@
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include <signal.h>
+#include <stdlib.h>
 
 #include "libgnome/libgnome.h"
+#include "libgnomeui/libgnomeui.h"
 #include "manager.h"
 
 /* The name of the session to load.  */
@@ -73,6 +75,8 @@ ignore (int sig)
 int
 main (int argc, char *argv[])
 {
+  char *ep;
+
   argp_program_version = VERSION;
 
   /* Initialize the i18n stuff */
@@ -82,9 +86,14 @@ main (int argc, char *argv[])
   initialize_ice ();
   /* FIXME: this is debugging that can eventually be removed.  */
   fprintf (stderr, "SESSION_MANAGER=%s\n", getenv ("SESSION_MANAGER"));
-
+  gnome_client_disable_master_connection ();
   gnome_init ("gnome-session", &parser, argc, argv, 0, NULL);
 
+  /* Make sure children see the right value for DISPLAY.  This is
+     useful if --display was specified on the command line.  */
+  ep = g_copy_strings ("DISPLAY=", gdk_get_display (), NULL);
+  putenv (ep);
+
   ignore (SIGPIPE);
   read_session (session);
 
