@@ -34,7 +34,7 @@ GNOME::Panel_var panel_client;
 typedef struct _CallbackInfo CallbackInfo;
 struct _CallbackInfo {
 	char *name;
-	gint applet_id;
+	int applet_id;
 	AppletCallbackFunc func;
 	gpointer data;
 };
@@ -55,6 +55,9 @@ void _gnome_applet_change_orient(int applet_id, int orient);
 int _gnome_applet_session_save(int applet_id, const char *cfgpath,
 			       const char *globcfgpath);
 int _gnome_applet_start_new_applet(const char *params);
+void _gnome_applet_back_change(int applet_id, int back_type,
+			       const char *pixmap, GdkColor *color);
+void _gnome_applet_tooltips_state(int enabled);
 
 END_GNOME_DECLS
 
@@ -99,6 +102,31 @@ public:
 		CHECK_COOKIE ();
 		::_gnome_applet_start_new_applet(param);
 	}
+	void back_change (const char *ccookie,
+			  CORBA::Short applet_id,
+			  CORBA::Short back_type,
+			  const char *pixmap,
+			  CORBA::Short c_red,
+			  CORBA::Short c_green,
+			  CORBA::Short c_blue)
+	{
+		GdkColor color;
+		CHECK_COOKIE ();
+		
+		color.pixel = 1;
+		color.red = c_red;
+		color.green = c_green;
+		color.blue = c_blue;
+
+		::_gnome_applet_back_change(applet_id,back_type,
+					    pixmap, &color);
+	}
+	void tooltips_state (const char *ccookie,
+			     CORBA::Short enabled)
+	{
+		CHECK_COOKIE ();
+		::_gnome_applet_tooltips_state(enabled);
+	}
 };
 
 int
@@ -107,6 +135,7 @@ gnome_panel_applet_init_corba (void)
 	char *name;
 	char *iior;
 	char hostname [1024];
+	char buf[256];
 	int i;
 	
 	gethostname (hostname, sizeof (hostname));
@@ -128,7 +157,10 @@ gnome_panel_applet_init_corba (void)
 	if(!iior)
 		return 0;
 
-	cookie = gnome_config_private_get_string ("/panel/Secret/cookie=");
+	g_snprintf(buf,256,"/panel/Secret/cookie-DISPLAY-%s=",
+		   getenv("DISPLAY"));
+	cookie = gnome_config_private_get_string (buf);
+
 
 	panel_initialize_corba (&orb_ptr, &boa_ptr);
 
@@ -147,6 +179,7 @@ gnome_panel_applet_reinit_corba (void)
 	char *name;
 	char *iior;
 	char hostname [1024];
+	char buf[256];
 	int i;
 	
 	gethostname (hostname, sizeof (hostname));
@@ -168,7 +201,9 @@ gnome_panel_applet_reinit_corba (void)
 	if(!iior)
 		return 0;
 
-	cookie = gnome_config_private_get_string ("/panel/Secret/cookie=");
+	g_snprintf(buf,256,"/panel/Secret/cookie-DISPLAY-%s=",
+		   getenv("DISPLAY"));
+	cookie = gnome_config_private_get_string (buf);
 
 	CORBA::Object_var obj = orb_ptr->string_to_object (iior);
 	
@@ -177,7 +212,7 @@ gnome_panel_applet_reinit_corba (void)
 }
 
 static CallbackInfo *
-get_callback_info(gint applet_id, gchar *name)
+get_callback_info(int applet_id, char *name)
 {
 	GList *list;
 	for(list=applet_callbacks;list!=NULL;list=g_list_next(list)) {
@@ -188,8 +223,8 @@ get_callback_info(gint applet_id, gchar *name)
 	return NULL;
 }
 
-static gchar*
-make_sane_name(gchar *name)
+static char*
+make_sane_name(char *name)
 {
 	if(!name)
 		return NULL;
@@ -204,6 +239,7 @@ make_sane_name(gchar *name)
 void
 gnome_panel_applet_register_callback(int applet_id,
 				     char *name,
+				     char *stock_item,
 				     char *menutext,
 				     AppletCallbackFunc func,
 				     gpointer data)
@@ -227,7 +263,8 @@ gnome_panel_applet_register_callback(int applet_id,
 	info->data = data;
 
 	/*register the callback with the panel*/
-	panel_client->applet_add_callback(cookie,applet_id,name,menutext);
+	panel_client->applet_add_callback(cookie,applet_id,name,
+					  stock_item,menutext);
 }
 
 /*removes a callback from the callback hash*/
@@ -247,9 +284,10 @@ gnome_panel_applet_unregister_callback(int applet_id,
 void
 gnome_panel_applet_register_callback_dir(int applet_id,
 					 char *name,
+					 char *stock_item,
 					 char *menutext)
 {
-	gchar *n;
+	char *n;
 	/*skip over leading '/'s*/
 	name = make_sane_name(name);
 	g_return_if_fail(name!=NULL);
@@ -259,7 +297,7 @@ gnome_panel_applet_register_callback_dir(int applet_id,
 	else
 		n = g_strdup(name);
 	/*unregister the dir with the panel*/
-	panel_client->applet_add_callback(cookie,applet_id,n,menutext);
+	panel_client->applet_add_callback(cookie,applet_id,n,stock_item,menutext);
 	g_free(n);
 }
 
@@ -268,7 +306,7 @@ void
 gnome_panel_applet_unregister_callback_dir(int applet_id,
 					   char *name)
 {
-	gchar *n;
+	char *n;
 
 	/*skip over leading '/'s*/
 	name = make_sane_name(name);
@@ -285,12 +323,12 @@ gnome_panel_applet_unregister_callback_dir(int applet_id,
 }
 
 /*catch events relevant to the panel and notify the panel*/
-static gint
+static int
 applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	int ourid = PTOI(data);
+	int ourid = GPOINTER_TO_INT(data);
 	GdkEventButton *bevent;
-	gint in_drag;
+	int in_drag;
 
 	switch (event->type) {
 		case GDK_BUTTON_PRESS:
@@ -334,7 +372,7 @@ listening_parent(GtkWidget *widget)
 	return widget;
 }
 
-static gint
+static int
 applet_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
 	switch (event->type) {
@@ -374,7 +412,7 @@ bind_top_applet_events(GtkWidget *widget, int applet_id)
 	gtk_signal_connect(GTK_OBJECT(widget),
 			   "event",
 			   GTK_SIGNAL_FUNC(applet_event),
-			   ITOP(applet_id));
+			   GINT_TO_POINTER(applet_id));
 
 	if (GTK_IS_CONTAINER(widget))
 		gtk_container_foreach (GTK_CONTAINER (widget),
@@ -472,21 +510,21 @@ gnome_panel_applet_register (GtkWidget *widget, int applet_id)
 }
 
 char *
-gnome_panel_applet_abort_id (gint applet_id)
+gnome_panel_applet_abort_id (int applet_id)
 {
 	panel_client->applet_abort_id(cookie, applet_id);
 
 	return 0;
 }
 
-gint
-gnome_panel_applet_get_panel_orient (gint applet_id)
+int
+gnome_panel_applet_get_panel_orient (int applet_id)
 {
 	return panel_client->applet_get_panel_orient(cookie, applet_id);
 }
 
 char *
-gnome_panel_applet_remove_from_panel (gint applet_id)
+gnome_panel_applet_remove_from_panel (int applet_id)
 {
 	panel_client->applet_remove_from_panel(cookie, applet_id);
 
@@ -494,7 +532,7 @@ gnome_panel_applet_remove_from_panel (gint applet_id)
 }
 
 char *
-gnome_panel_applet_add_tooltip (gint applet_id, char *tooltip)
+gnome_panel_applet_add_tooltip (int applet_id, char *tooltip)
 {
 	panel_client->applet_add_tooltip(cookie, applet_id,tooltip);
 
@@ -502,7 +540,7 @@ gnome_panel_applet_add_tooltip (gint applet_id, char *tooltip)
 }
 
 char *
-gnome_panel_applet_remove_tooltip (gint applet_id)
+gnome_panel_applet_remove_tooltip (int applet_id)
 {
 	panel_client->applet_remove_tooltip(cookie, applet_id);
 
@@ -531,7 +569,7 @@ gnome_panel_applet_request_glob_cfg (char **globcfgpath)
 }
 
 void
-gnome_panel_applet_cleanup(gint applet_id)
+gnome_panel_applet_cleanup(int applet_id)
 {
 	GList *list;
 	GList *nlist;
@@ -542,8 +580,8 @@ gnome_panel_applet_cleanup(gint applet_id)
 		if(info->applet_id == applet_id) {
 			g_free(info->name);
 			g_list_remove_link(applet_callbacks,list);
+			g_list_free(list);
 			g_free(info);
-
 		}
 		list = nlist;
 	}
@@ -551,11 +589,11 @@ gnome_panel_applet_cleanup(gint applet_id)
 
 
 char *
-gnome_panel_sync_config (void)
+gnome_panel_sync_config (int applet_id)
 {
 	char *result;
 
-	panel_client->sync_config (cookie);
+	panel_client->sync_config (cookie,applet_id);
 
 	return 0;
 }
@@ -574,4 +612,16 @@ void
 applet_corba_gtk_main (char *str)
 {
 	boa_ptr->impl_is_ready (CORBA::ImplementationDef::_nil());
+#ifdef HAVE_MICO_ORB_RUN       
+	orb_ptr->run ();
+#endif	
+}
+
+void
+applet_corba_gtk_main_quit (void)
+{
+	boa_ptr->deactivate_impl (CORBA::ImplementationDef::_nil());
+#ifdef HAVE_MICO_ORB_RUN       
+	orb_ptr->shutdown (TRUE);
+#endif	
 }
