@@ -1,8 +1,10 @@
+#include <config.h>
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
 #include <applet-widget.h>
 #include <applet-lib.h>
+#include "mico-parse.h"
 
 static void applet_widget_class_init	(AppletWidgetClass *klass);
 static void wapplet_widget_init		(AppletWidget      *applet_widget);
@@ -11,23 +13,35 @@ typedef void (*AppletWidgetOrientSignal) (GtkObject * object,
 					  PanelOrientType orient,
 					  gpointer data);
 
-typedef gint (*AppletWidgetSaveSignal) (GtkObject * object,
+typedef int (*AppletWidgetSaveSignal) (GtkObject * object,
 				        char *cfgpath,
 				        char *globcfgpath,
 				        gpointer data);
 
-static GList *applet_widgets = NULL;
-static gint applet_count = 0;
+typedef void (*AppletWidgetBackSignal) (GtkObject * object,
+					PanelBackType type,
+					char *pixmap,
+					GdkColor *color,
+					gpointer data);
 
-static gint do_multi = FALSE;
-static gint die_on_last = TRUE;
+typedef void (*AppletWidgetTooltipSignal) (GtkObject * object,
+					   int enabled,
+					   gpointer data);
+
+static GList *applet_widgets = NULL;
+static int applet_count = 0;
+
+static int do_multi = FALSE;
+static int die_on_last = TRUE;
 
 static GtkPlugClass *parent_class;
 
 static AppletStartNewFunc start_new_func=NULL;
 static gpointer start_new_func_data=NULL;
 
-static gchar *myinvoc= NULL;
+static char *myinvoc= NULL;
+
+static GtkTooltips *applet_tooltips=NULL;
 
 guint
 applet_widget_get_type ()
@@ -53,17 +67,20 @@ applet_widget_get_type ()
 
 enum {
 	CHANGE_ORIENT_SIGNAL,
+	SAVE_SESSION_SIGNAL,
 	SESSION_SAVE_SIGNAL,
+	BACK_CHANGE_SIGNAL,
+	TOOLTIP_STATE_SIGNAL,
 	LAST_SIGNAL
 };
 
-static gint applet_widget_signals[LAST_SIGNAL] = {0,0};
+static int applet_widget_signals[LAST_SIGNAL] = {0,0,0,0,0};
 
 static void
-gtk_applet_widget_marshal_signal_orient (GtkObject * object,
-				         GtkSignalFunc func,
-				         gpointer func_data,
-				         GtkArg * args)
+applet_widget_marshal_signal_orient (GtkObject * object,
+				     GtkSignalFunc func,
+				     gpointer func_data,
+				     GtkArg * args)
 {
 	AppletWidgetOrientSignal rfunc;
 
@@ -74,13 +91,13 @@ gtk_applet_widget_marshal_signal_orient (GtkObject * object,
 }
 
 static void
-gtk_applet_widget_marshal_signal_save (GtkObject * object,
-				       GtkSignalFunc func,
-				       gpointer func_data,
-				       GtkArg * args)
+applet_widget_marshal_signal_save (GtkObject * object,
+				   GtkSignalFunc func,
+				   gpointer func_data,
+				   GtkArg * args)
 {
 	AppletWidgetSaveSignal rfunc;
-	gint *retval;
+	int *retval;
 
 	rfunc = (AppletWidgetSaveSignal) func;
 
@@ -89,6 +106,40 @@ gtk_applet_widget_marshal_signal_save (GtkObject * object,
 	*retval = (*rfunc) (object, GTK_VALUE_STRING (args[0]),
 		  	    GTK_VALUE_STRING (args[1]),
 		  	    func_data);
+	
+	/*make applets that forget to do this not fsckup*/
+	gnome_config_sync();
+	gnome_config_drop_all();
+}
+
+static void
+applet_widget_marshal_signal_back (GtkObject * object,
+				   GtkSignalFunc func,
+				   gpointer func_data,
+				   GtkArg * args)
+{
+	AppletWidgetBackSignal rfunc;
+
+	rfunc = (AppletWidgetBackSignal) func;
+
+	(*rfunc) (object, GTK_VALUE_ENUM (args[0]),
+		  GTK_VALUE_POINTER (args[1]),
+		  GTK_VALUE_POINTER (args[2]),
+		  func_data);
+}
+
+static void
+applet_widget_marshal_signal_tooltip (GtkObject * object,
+				      GtkSignalFunc func,
+				      gpointer func_data,
+				      GtkArg * args)
+{
+	AppletWidgetTooltipSignal rfunc;
+
+	rfunc = (AppletWidgetTooltipSignal) func;
+
+	(*rfunc) (object, GTK_VALUE_INT (args[0]),
+		  func_data);
 }
 
 static void
@@ -106,26 +157,61 @@ applet_widget_class_init (AppletWidgetClass *class)
 			       object_class->type,
 			       GTK_SIGNAL_OFFSET(AppletWidgetClass,
 			       			 change_orient),
-			       gtk_applet_widget_marshal_signal_orient,
+			       applet_widget_marshal_signal_orient,
 			       GTK_TYPE_NONE,
 			       1,
 			       GTK_TYPE_ENUM);
+	applet_widget_signals[SAVE_SESSION_SIGNAL] =
+		gtk_signal_new("save_session",
+			       GTK_RUN_LAST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET(AppletWidgetClass,
+			       			 save_session),
+			       applet_widget_marshal_signal_save,
+			       GTK_TYPE_BOOL,
+			       2,
+			       GTK_TYPE_STRING,
+			       GTK_TYPE_STRING);
+	/*this one should be phased out*/
 	applet_widget_signals[SESSION_SAVE_SIGNAL] =
 		gtk_signal_new("session_save",
 			       GTK_RUN_LAST,
 			       object_class->type,
 			       GTK_SIGNAL_OFFSET(AppletWidgetClass,
 			       			 session_save),
-			       gtk_applet_widget_marshal_signal_save,
+			       applet_widget_marshal_signal_save,
 			       GTK_TYPE_BOOL,
 			       2,
 			       GTK_TYPE_STRING,
 			       GTK_TYPE_STRING);
+	applet_widget_signals[BACK_CHANGE_SIGNAL] =
+		gtk_signal_new("back_change",
+			       GTK_RUN_LAST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET(AppletWidgetClass,
+			       			 back_change),
+			       applet_widget_marshal_signal_back,
+			       GTK_TYPE_NONE,
+			       3,
+			       GTK_TYPE_ENUM,
+			       GTK_TYPE_POINTER,
+			       GTK_TYPE_POINTER);
+	applet_widget_signals[TOOLTIP_STATE_SIGNAL] =
+		gtk_signal_new("tooltip_state",
+			       GTK_RUN_LAST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET(AppletWidgetClass,
+			       			 tooltip_state),
+			       applet_widget_marshal_signal_tooltip,
+			       GTK_TYPE_NONE,
+			       1,
+			       GTK_TYPE_INT);
 
 	gtk_object_class_add_signals(object_class,applet_widget_signals,
 				     LAST_SIGNAL);
 
 	class->change_orient = NULL;
+	class->save_session = NULL;
 	class->session_save = NULL;
 }
 
@@ -135,16 +221,18 @@ wapplet_widget_init (AppletWidget *applet_widget)
 	applet_widget->applet_id = -1;
 }
 
-static gint
+static int
 applet_widget_destroy(GtkWidget *w, gpointer data)
 {
 	AppletWidget *applet = APPLET_WIDGET(w);
-	if(!applet->cfgpath)
+	if(!applet->privcfgpath)
 		return FALSE;
-	g_free(applet->cfgpath);
+	g_free(applet->privcfgpath);
 	g_free(applet->globcfgpath);
-	applet->cfgpath = NULL;
+	g_free(applet->cfgpath);
+	applet->privcfgpath = NULL;
 	applet->globcfgpath = NULL;
+	applet->cfgpath = NULL;
 	gnome_panel_applet_cleanup(applet->applet_id);
 	if(GTK_BIN(w)->child == NULL)
 		gnome_panel_applet_abort_id(applet->applet_id);
@@ -152,7 +240,8 @@ applet_widget_destroy(GtkWidget *w, gpointer data)
 	applet_count--;
 
 	if(die_on_last && applet_count == 0)
-		gtk_exit(0);
+		applet_corba_gtk_main_quit();
+		/*gtk_exit(0);*/
 
 	return FALSE;
 }
@@ -164,9 +253,9 @@ applet_widget_remove_from_panel(AppletWidget *applet)
 }
 
 void
-applet_widget_sync_config(void)
+applet_widget_sync_config(AppletWidget *applet)
 {
-	gnome_panel_sync_config();
+	gnome_panel_sync_config(applet->applet_id);
 }
 
 void
@@ -177,7 +266,18 @@ applet_widget_register_callback(AppletWidget *applet,
 				gpointer data)
 {
 	gnome_panel_applet_register_callback (applet->applet_id,name,
-					      menutext,func,data);
+					      "",menutext,func,data);
+}
+void
+applet_widget_register_stock_callback(AppletWidget *applet,
+				      char *name,
+				      char *stock_type,
+				      char *menutext,
+				      AppletCallbackFunc func,
+				      gpointer data)
+{
+	gnome_panel_applet_register_callback (applet->applet_id,name,
+					      stock_type,menutext,func,data);
 }
 
 void
@@ -188,9 +288,21 @@ applet_widget_unregister_callback(AppletWidget *applet,
 }
 
 void
-applet_widget_register_callback_dir(AppletWidget *applet, char *name, char *menutext)
+applet_widget_register_callback_dir(AppletWidget *applet,
+				    char *name,
+				    char *menutext)
 {
-	gnome_panel_applet_register_callback_dir (applet->applet_id,name,menutext);
+	gnome_panel_applet_register_callback_dir (applet->applet_id,name,
+						  "",menutext);
+}
+void
+applet_widget_register_stock_callback_dir(AppletWidget *applet,
+					  char *name,
+					  char *stock_type,
+					  char *menutext)
+{
+	gnome_panel_applet_register_callback_dir (applet->applet_id,name,
+						  stock_type,menutext);
 }
 
 void
@@ -201,14 +313,14 @@ applet_widget_unregister_callback_dir(AppletWidget *applet, char *name)
 
 
 GtkWidget *
-applet_widget_new_with_param(const gchar *param)
+applet_widget_new_with_param(const char *param)
 {
 	AppletWidget *applet;
 	char *result;
-	char *cfgpath;
+	char *privcfgpath;
 	char *globcfgpath;
 	guint32 winid;
-	gint applet_id;
+	int applet_id;
 
 	if(!param)
 		param="";
@@ -216,7 +328,7 @@ applet_widget_new_with_param(const gchar *param)
 	result = gnome_panel_applet_request_id(myinvoc, param,
 					       do_multi?FALSE:TRUE,
 					       &applet_id,
-					       &cfgpath, &globcfgpath,
+					       &privcfgpath, &globcfgpath,
 					       &winid);
 	if (result)
 		g_error("Could not talk to the panel: %s\n", result);
@@ -227,8 +339,9 @@ applet_widget_new_with_param(const gchar *param)
 	GTK_PLUG(applet)->same_app = FALSE;
 
 	applet->applet_id = applet_id;
-	applet->cfgpath = cfgpath;
+	applet->privcfgpath = privcfgpath;
 	applet->globcfgpath = globcfgpath;
+	applet->cfgpath = g_copy_strings(privcfgpath,"dummy_section/",NULL);
 
 	gtk_signal_connect(GTK_OBJECT(applet),"destroy",
 			   GTK_SIGNAL_FUNC(applet_widget_destroy),
@@ -241,7 +354,7 @@ applet_widget_new_with_param(const gchar *param)
 	return GTK_WIDGET(applet);
 }
 
-gint
+int
 applet_widget_get_applet_count()
 {
 	return applet_count;
@@ -261,7 +374,15 @@ applet_widget_add(AppletWidget *applet, GtkWidget *widget)
 }
 
 void
-applet_widget_set_tooltip(AppletWidget *applet, gchar *text)
+applet_widget_set_widget_tooltip(AppletWidget *applet,
+				 GtkWidget *widget,
+				 char *text)
+{
+	gtk_tooltips_set_tip (applet_tooltips,widget,text,NULL);
+}
+
+void
+applet_widget_set_tooltip(AppletWidget *applet, char *text)
 {
 	if(text)
 		gnome_panel_applet_add_tooltip (applet->applet_id, text);
@@ -277,7 +398,7 @@ applet_widget_get_panel_orient(AppletWidget *applet)
 }
 
 AppletWidget*
-applet_widget_get_by_id(gint applet_id)
+applet_widget_get_by_id(int applet_id)
 {
 	GList *list;
 	for(list = applet_widgets;list!=NULL;list=g_list_next(list)) {
@@ -295,9 +416,9 @@ applet_widget_init(char *app_id,
 		   char **argv,
 		   unsigned int flags,
 		   int *arg_index,
-		   gchar *argv0,
-		   gint last_die,
-		   gint multi_applet,
+		   char *argv0,
+		   int last_die,
+		   int multi_applet,
 		   AppletStartNewFunc new_func,
 		   gpointer new_func_data)
 {
@@ -320,10 +441,13 @@ applet_widget_init(char *app_id,
 
 	panel_corba_register_arguments();
 
+	gnome_client_disable_master_connection ();
 	ret = gnome_init(app_id,app_parser,argc,argv,flags,arg_index);
 
 	if (!gnome_panel_applet_init_corba())
 		g_error("Could not communicate with the panel\n");
+	
+	applet_tooltips = gtk_tooltips_new();
 
 	return ret;
 }
@@ -356,13 +480,23 @@ _gnome_applet_session_save(int applet_id, const char *cfgpath, const char *globc
 
 	char *cfg = g_strdup(cfgpath);
 	char *globcfg = g_strdup(globcfgpath);
-	gint return_val = FALSE;
+	int return_val = FALSE;
 
 	applet = applet_widget_get_by_id(applet_id);
 	if(applet) {
 		gtk_signal_emit(GTK_OBJECT(applet),
-				applet_widget_signals[SESSION_SAVE_SIGNAL],
+				applet_widget_signals[SAVE_SESSION_SIGNAL],
 				cfg,globcfg,&return_val);
+
+		/*this should be ripped out when session_save is abandoned
+		  for save_session*/
+		{
+			char *oldcfg = g_copy_strings(cfg,"dummy_section/",NULL);
+			gtk_signal_emit(GTK_OBJECT(applet),
+					applet_widget_signals[SESSION_SAVE_SIGNAL],
+					oldcfg,globcfg,&return_val);
+			g_free(oldcfg);
+		}
 	}
 	g_free(cfg);
 	g_free(globcfg);
@@ -383,13 +517,46 @@ _gnome_applet_start_new_applet(const char *param)
 		(*start_new_func)(param,start_new_func_data);
 }
 
-/* convenience function for multi applets */
-gchar *
-make_param_string(gint argc, char *argv[])
+void
+_gnome_applet_back_change(int applet_id,
+			  int back_type,
+			  const char *pixmap,
+			  GdkColor *color)
 {
-	gchar *s;
-	gint i;
-	gint len=0;
+	AppletWidget *applet;
+
+	applet = applet_widget_get_by_id(applet_id);
+	if(applet) {
+		gtk_signal_emit(GTK_OBJECT(applet),
+				applet_widget_signals[BACK_CHANGE_SIGNAL],
+				back_type,pixmap,color);
+	}
+}
+
+void
+_gnome_applet_tooltips_state(int enabled)
+{
+	GList *list;
+	if(enabled)
+		gtk_tooltips_enable(applet_tooltips);
+	else
+		gtk_tooltips_disable(applet_tooltips);
+
+	for(list=applet_widgets;list!=NULL;list=g_list_next(list)) {
+		gtk_signal_emit(GTK_OBJECT(list->data),
+				applet_widget_signals[TOOLTIP_STATE_SIGNAL],
+				enabled);
+	}
+}
+
+
+/* convenience function for multi applets */
+char *
+make_param_string(int argc, char *argv[])
+{
+	char *s;
+	int i;
+	int len=0;
 
 	for(i=1;i<argc;i++)
 		len = strlen(argv[i])+1;
