@@ -574,12 +574,6 @@ make_hidebutton(CornerWidget *corner,
 	return w;
 }
 
-static int
-corner_widget_destroy(GtkWidget *w, gpointer data)
-{
-	return FALSE;
-}
-
 static void
 corner_widget_init (CornerWidget *corner)
 {
@@ -635,10 +629,6 @@ corner_widget_init (CornerWidget *corner)
 	gtk_signal_connect(GTK_OBJECT(corner), "enter_notify_event",
 			   GTK_SIGNAL_FUNC(corner_enter_notify),
 			   NULL);
-	gtk_signal_connect(GTK_OBJECT(corner),
-			   "destroy",
-			   GTK_SIGNAL_FUNC(corner_widget_destroy),
-			   NULL);
 	corner->pos = CORNER_NE;
 	corner->state = CORNER_SHOWN;
 }
@@ -702,7 +692,6 @@ corner_widget_change_params(CornerWidget *corner,
 			    int fit_pixmap_bg,
 			    GdkColor *back_color)
 {
-	PanelOrientation oldorient;
 	CornerPos oldpos;
 	CornerState oldstate;
 	
@@ -714,10 +703,8 @@ corner_widget_change_params(CornerWidget *corner,
 	oldstate = corner->state;
 	corner->state = state;
 
-	oldorient = PANEL_WIDGET(corner->panel)->orient;
-
 	/*avoid flicker during size_request*/
-	if(oldorient != orient)
+	if(PANEL_WIDGET(corner->panel)->orient != orient)
 		corner_widget_request_cube = TRUE;
 	
 	panel_widget_change_params(PANEL_WIDGET(corner->panel),
