@@ -12,16 +12,14 @@ typedef struct {
 	char *tooltip;
 	GtkWidget *button;
 	GtkWidget *drawer;
-	PanelOrientType orient;
 } Drawer;
 
 void load_drawer_applet(char *params, char *pixmap, char *tooltip,
-			int pos, PanelWidget *panel);
+			PanelWidget *panel, int pos);
 
 void set_drawer_applet_orient(Drawer *drawer, PanelOrientType orient);
 
-void reposition_drawer(Drawer *drawer);
-void drawer_properties(Drawer *drawer);
+void add_drawer_properties_page(GtkWidget *dialog, Drawer *drawer);
 
 END_GNOME_DECLS
 
