@@ -61,6 +61,20 @@ launch (GtkWidget *widget, GdkEvent *event, void *data)
 	return FALSE;
 }
 
+static int
+destroy_launcher(GtkWidget *widget, gpointer data)
+{
+	Launcher *launcher = data;
+	GtkWidget *prop_dialog = gtk_object_get_data(GTK_OBJECT(launcher->button),
+						     LAUNCHER_PROPERTIES);
+	if(prop_dialog)
+		gtk_widget_destroy(prop_dialog);
+	gnome_desktop_entry_free(launcher->dentry);
+	g_free(launcher);
+	return FALSE;
+}
+
+
 Launcher *
 create_launcher (char *parameters, GnomeDesktopEntry *dentry)
 {
@@ -129,6 +143,10 @@ create_launcher (char *parameters, GnomeDesktopEntry *dentry)
 				    "event",
 				    (GtkSignalFunc) launch,
 				    dentry);
+	
+	gtk_signal_connect (GTK_OBJECT(launcher->button), "destroy",
+			    GTK_SIGNAL_FUNC(destroy_launcher),
+			    launcher);
 
 	gtk_object_set_user_data(GTK_OBJECT(launcher->button), launcher);
 
@@ -258,14 +276,14 @@ launcher_properties(Launcher *launcher)
 
 static void
 _load_launcher_applet(char *params, GnomeDesktopEntry *dentry,
-		      int pos, PanelWidget *panel)
+		      PanelWidget *panel, int pos)
 {
 	Launcher *launcher;
 
 	launcher = create_launcher(params,dentry);
 
 	if(launcher) {
-		register_toy(launcher->button,launcher, pos,panel,
+		register_toy(launcher->button,launcher, panel, pos,
 			     APPLET_LAUNCHER);
 
 		gtk_tooltips_set_tip (panel_tooltips,
@@ -284,7 +302,7 @@ really_add_launcher(GtkWidget *d,int button, gpointer data)
 	GnomeDEntryEdit *dedit = GNOME_DENTRY_EDIT(data);
 	if(button==0)
 		_load_launcher_applet(NULL, gnome_dentry_get_dentry(dedit),
-				      0, current_panel);
+				      current_panel, 0);
 	gtk_widget_destroy(d);
 }
 
@@ -318,7 +336,7 @@ ask_about_launcher(void)
 }
 
 void
-load_launcher_applet(char *params, int pos, PanelWidget *panel)
+load_launcher_applet(char *params, PanelWidget *panel, int pos)
 {
-	_load_launcher_applet(params,NULL,pos,panel);
+	_load_launcher_applet(params,NULL,panel, pos);
 }
