@@ -20,7 +20,7 @@ struct _Menu {
 };
 
 void load_menu_applet(char *params, int main_menu_type,
-		      int pos, PanelWidget *panel);
+		      PanelWidget *panel, int pos);
 
 void set_menu_applet_orient(Menu *menu, PanelOrientType orient);
 
@@ -32,6 +32,9 @@ void make_panel_submenu (GtkWidget *menu, int fake_submenus);
 
 GtkWidget * create_panel_root_menu(GtkWidget *panel);
 
+void menu_properties(Menu *menu);
+
+
 END_GNOME_DECLS
 
 #endif
