@@ -48,6 +48,7 @@ int pw_minimized_size = 6;
 int pw_minimize_delay = 300;
 int pw_disable_animations = FALSE;
 PanelMovementType pw_movement_type = PANEL_SWITCH_MOVE;
+int pw_applet_padding = 3;
 
 static char *image_drop_types[] = {"url:ALL", "application/x-color"};
 
@@ -387,18 +388,17 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 	g_return_if_fail (container != NULL);
 	g_return_if_fail (IS_PANEL_WIDGET (container));
 	g_return_if_fail (widget != NULL);
-
+	
 	panel = PANEL_WIDGET (container);
 	
 	ad = gtk_object_get_data(GTK_OBJECT(widget), PANEL_APPLET_DATA);
-
-	if (GTK_CONTAINER_CLASS (parent_class)->remove)
-		(* GTK_CONTAINER_CLASS (parent_class)->remove) (container,
-								widget);
-
 	p = gtk_object_get_data(GTK_OBJECT(widget),
 				PANEL_APPLET_ASSOC_PANEL_KEY);
 
+	gtk_widget_ref(widget);
+	if (GTK_CONTAINER_CLASS (parent_class)->remove)
+		(* GTK_CONTAINER_CLASS (parent_class)->remove) (container,
+								widget);
 	if(ad) {
 		PanelWidget *panel = PANEL_WIDGET (container);
 
@@ -413,6 +413,7 @@ panel_widget_cremove(GtkContainer *container, GtkWidget *widget)
 	gtk_signal_emit(GTK_OBJECT(container),
 			panel_widget_signals[APPLET_REMOVED_SIGNAL],
 			widget);
+	gtk_widget_unref(widget);
 }
 
 
@@ -583,8 +584,8 @@ panel_widget_switch_move(PanelWidget *panel, AppletData *ad, int moveby)
 
 	if(finalpos >= panel->size)
 		finalpos = panel->size-1;
-	else if(finalpos < 0)
-		finalpos = 0;
+	else if(finalpos < pw_applet_padding)
+		finalpos = pw_applet_padding;
 
 	while((ad->pos+ad->cells-1)<finalpos) {
 		pos = panel_widget_get_right_switch_pos(panel,list);
@@ -648,6 +649,11 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 	GList *list;
 	requisition->height = 0;
 	requisition->width = 0;
+	if(panel->orient == PANEL_HORIZONTAL)
+		requisition->width = pw_applet_padding;
+	else
+		requisition->height = pw_applet_padding;
+
 	for(list = panel->applet_list; list!=NULL; list = g_list_next(list)) {
 		AppletData *ad = list->data;
 		gtk_widget_size_request (ad->applet, &ad->applet->requisition);
@@ -659,7 +665,8 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 			}
 			if(panel->packed)
 				requisition->width +=
-					ad->applet->requisition.width;
+					ad->applet->requisition.width +
+					pw_applet_padding;
 		} else {
 			if(requisition->width <
 			   ad->applet->requisition.width) {
@@ -668,7 +675,8 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 			}
 			if(panel->packed)
 				requisition->height +=
-					ad->applet->requisition.height;
+					ad->applet->requisition.height +
+					pw_applet_padding;
 		}
 	}
 	if(!panel->packed) {
@@ -680,7 +688,6 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 	}
 }
 
-/*FIXME: do rightsticking*/
 static void
 panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
@@ -707,7 +714,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		panel_widget_right_stick(panel,old_size);
 
 	if(panel->packed) {
-		i = 0;
+		i = pw_applet_padding;
 		for(list = panel->applet_list;
 		    list!=NULL;
 		    list = g_list_next(list)) {
@@ -719,11 +726,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				send_move = g_list_prepend(send_move,ad);
 			}
 			if(panel->orient == PANEL_HORIZONTAL) {
-				ad->cells = ad->applet->requisition.width;
+				ad->cells = ad->applet->requisition.width +
+					pw_applet_padding;
 				challoc.x = ad->pos;
 				challoc.y = (allocation->height - ad->applet->requisition.height) / 2;
 			} else {
-				ad->cells = ad->applet->requisition.height;
+				ad->cells = ad->applet->requisition.height +
+					pw_applet_padding;
 				challoc.x = (allocation->width - ad->applet->requisition.width) / 2;
 				challoc.y = ad->pos;
 			}
@@ -740,17 +749,19 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 			AppletData *ad = list->data;
 			
 			if(panel->orient == PANEL_HORIZONTAL)
-				ad->cells = ad->applet->requisition.width;
+				ad->cells = ad->applet->requisition.width +
+					pw_applet_padding;
 			else
-				ad->cells = ad->applet->requisition.height;
+				ad->cells = ad->applet->requisition.height +
+					pw_applet_padding;
 			if(ad->pos+ad->cells > i) {
 				ad->pos = i - ad->cells;
 				send_move = g_list_prepend(send_move,ad);
 			}
 			i = ad->pos;
 		}
-		if(i<0) {
-			i = 0;
+		if(i<pw_applet_padding) {
+			i = pw_applet_padding;
 			for(list = panel->applet_list;
 			    list!=NULL;
 			    list = g_list_next(list)) {
@@ -1364,8 +1375,8 @@ panel_widget_get_free_spot(PanelWidget *panel, AppletData *ad)
 	list = panel->applet_list;
 
 	start = place-(ad->cells/2);
-	if(start<0)
-		start = 0;
+	if(start<pw_applet_padding)
+		start = pw_applet_padding;
 	for(e=0,i=start;i<panel->size;i++) {
 		GtkWidget *applet;
 		list = walk_up_to(i,list);
@@ -1628,6 +1639,10 @@ panel_widget_applet_destroy(GtkWidget *applet, gpointer data)
 
 	if(panel->currently_dragged_applet == ad)
 		panel->currently_dragged_applet = NULL;
+	
+	panel->applet_list = g_list_remove(panel->applet_list,ad);
+	panel->no_window_applet_list =
+		g_list_remove (panel->no_window_applet_list, ad);
 
 	g_free(ad);
 	return FALSE;
@@ -1683,7 +1698,7 @@ panel_widget_find_empty_pos(PanelWidget *panel, int pos)
 		}
 	}
 
-	for(i=pos;i>=0;i--) {
+	for(i=pos;i>=pw_applet_padding;i--) {
 		list = walk_up_to(i,list);
 		if(!is_in_applet(i,list->data)) {
 			left = i;
@@ -1718,17 +1733,21 @@ panel_widget_add_full (PanelWidget *panel, GtkWidget *applet, int pos, int bind_
 	g_return_val_if_fail(panel!=NULL,-1);
 	g_return_val_if_fail(applet!=NULL,-1);
 	g_return_val_if_fail(pos>=0,-1);
-	
+
 	ad = gtk_object_get_data(GTK_OBJECT(applet),PANEL_APPLET_DATA);
 
 	if(ad)
 		pos = ad->pos;
 
+	if(pos<pw_applet_padding)
+		pos = pw_applet_padding;
+
 	if(pw_movement_type == PANEL_SWITCH_MOVE ||
 	   panel->packed) {
 		if(get_applet_list_pos(panel,pos)) 
-			pos++; /*this is a slight hack so that this applet is
-				 inserted AFTER an applet with this pos number*/
+			/*this is a slight hack so that this applet is
+			  inserted AFTER an applet with this pos number*/
+			pos++;
 	} else
 		pos = panel_widget_find_empty_pos(panel,pos);
 
@@ -1821,10 +1840,14 @@ panel_widget_move (PanelWidget *panel, GtkWidget *applet, int pos)
 	panel->applet_list = g_list_remove(panel->applet_list,ad);
 	panel->no_window_applet_list =
 		g_list_remove(panel->no_window_applet_list,ad);
+	
+	if(pos<pw_applet_padding)
+		pos = pw_applet_padding;
 
 	if(get_applet_list_pos(panel,pos)) 
-		pos++; /*this is a slight hack so that this applet is
-			 inserted AFTER an applet with this pos number*/
+		/*this is a slight hack so that this applet is
+		  inserted AFTER an applet with this pos number*/
+		pos++;
 	if(pos==-1) return -1;
 
 	ad->pos = pos;
@@ -1954,7 +1977,8 @@ panel_widget_change_global(int explicit_step,
 			   int minimized_size,
 			   int minimize_delay,
 			   PanelMovementType move_type,
-			   int disable_animations)
+			   int disable_animations,
+			   int applet_padding)
 {
 	if(explicit_step>0)
 		pw_explicit_step=explicit_step;
@@ -1968,4 +1992,12 @@ panel_widget_change_global(int explicit_step,
 		pw_minimize_delay=minimize_delay;
 	pw_movement_type = move_type;
 	pw_disable_animations = disable_animations;
+
+	/*change padding on all panels NOW*/
+	if(pw_applet_padding != applet_padding) {
+		GList *li;
+		pw_applet_padding = applet_padding;
+		for(li=panels;li!=NULL;li=g_list_next(li))
+			gtk_widget_queue_resize(li->data);
+	}
 }
