@@ -68,7 +68,6 @@ get_def_panel_widget(GtkWidget *panel)
 	} else if(IS_DRAWER_WIDGET(panel)) {
 		return PANEL_WIDGET(DRAWER_WIDGET(panel)->panel);
 	}
-	puts("get_def_panel");
 	g_warning("unknown panel type");
 	return NULL;
 }
@@ -214,7 +213,7 @@ panel_realize(GtkWidget *widget, gpointer data)
 }
 
 /*we call this recursively*/
-static void orient_change_foreach(gpointer data, gpointer user_data);
+static void orient_change_foreach(GtkWidget *w, gpointer data);
 
 void
 orientation_change(int applet_id, PanelWidget *panel)
@@ -233,8 +232,8 @@ orientation_change(int applet_id, PanelWidget *panel)
 	} else if(info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
 		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
-		reposition_drawer(drawer);
 		set_drawer_applet_orient(drawer,get_applet_orient(panel));
+		gtk_widget_queue_resize(drawer->drawer);
 		gtk_container_foreach(GTK_CONTAINER(dw->panel),
 				      orient_change_foreach,
 				      (gpointer)dw->panel);
@@ -249,10 +248,11 @@ orientation_change(int applet_id, PanelWidget *panel)
 }
 
 static void
-orient_change_foreach(gpointer data, gpointer user_data)
+orient_change_foreach(GtkWidget *w, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(data),"applet_id"));
-	PanelWidget *panel = user_data;
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    "applet_id"));
+	PanelWidget *panel = data;
 	
 	orientation_change(applet_id,panel);
 }
@@ -319,10 +319,11 @@ back_change(int applet_id,
 
 
 static void
-back_change_foreach(gpointer data, gpointer user_data)
+back_change_foreach(GtkWidget *w, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(data),"applet_id"));
-	PanelWidget *panel = user_data;
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    "applet_id"));
+	PanelWidget *panel = data;
 
 	back_change(applet_id,panel);
 }
@@ -339,12 +340,13 @@ panel_back_change(GtkWidget *widget,
 	update_config_back(PANEL_WIDGET(widget));
 }
 
-static void state_hide_foreach(gpointer data, gpointer user_data);
+static void state_hide_foreach(GtkWidget *w, gpointer data);
 
 static void
-state_restore_foreach(gpointer data, gpointer user_data)
+state_restore_foreach(GtkWidget *w, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(data),"applet_id"));
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    "applet_id"));
 	AppletInfo *info = get_applet_info(applet_id);
 	
 	if(info->type == APPLET_DRAWER) {
@@ -365,9 +367,10 @@ state_restore_foreach(gpointer data, gpointer user_data)
 }
 
 static void
-state_hide_foreach(gpointer data, gpointer user_data)
+state_hide_foreach(GtkWidget *w, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(data),"applet_id"));
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    "applet_id"));
 	AppletInfo *info = get_applet_info(applet_id);
 
 	if(info->type == APPLET_DRAWER) {
@@ -442,13 +445,8 @@ static int
 panel_size_allocate(GtkWidget *widget, GtkAllocation *alloc, gpointer data)
 {
 	if(IS_DRAWER_WIDGET(widget)) {
-		Drawer *drawer = gtk_object_get_data(GTK_OBJECT(widget),
-						     DRAWER_PANEL_KEY);
-		if(!drawer)
-			return FALSE;
-
 		if(DRAWER_WIDGET(widget)->state == DRAWER_SHOWN)
-			reposition_drawer(drawer);
+			gtk_widget_queue_resize(widget);
 		panels_to_sync = TRUE;
 	}
 	return FALSE;
@@ -472,7 +470,8 @@ panel_applet_added_idle(gpointer data)
 static void
 panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(applet),"applet_id"));
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(applet),
+							    "applet_id"));
 	AppletInfo *info = get_applet_info(applet_id);
 	GtkWidget *panelw = gtk_object_get_data(GTK_OBJECT(widget),
 						PANEL_PARENT);
@@ -485,8 +484,10 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	   info && info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
 		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
-		if(dw->state == DRAWER_SHOWN)
+		if(dw->state == DRAWER_SHOWN) {
 			SNAPPED_WIDGET(panelw)->drawers_open++;
+			snapped_widget_pop_up(SNAPPED_WIDGET(panelw));
+		}
 	}
 
 	/*pop the panel up on addition*/
@@ -500,11 +501,12 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 }
 
 static void
-count_open_drawers(gpointer data, gpointer user_data)
+count_open_drawers(GtkWidget *w, gpointer data)
 {
-	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(data),"applet_id"));
+	int applet_id = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    "applet_id"));
 	AppletInfo *info = get_applet_info(applet_id);
-	int *count = user_data;
+	int *count = data;
 	if(info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
 		if(DRAWER_WIDGET(drawer->drawer)->state == DRAWER_SHOWN)
@@ -744,6 +746,8 @@ panel_destroy(GtkWidget *widget, gpointer data)
 	PanelData *pd = gtk_object_get_user_data(GTK_OBJECT(widget));
 	GtkWidget *panel_menu = data;
 
+	kill_config_dialog(widget);
+
 	if(IS_DRAWER_WIDGET(widget)) {
 		PanelWidget *panel = PANEL_WIDGET(DRAWER_WIDGET(widget)->panel);
 		if(panel->master_widget) {
@@ -766,7 +770,7 @@ panel_destroy(GtkWidget *widget, gpointer data)
 	
 	panel_list = g_list_remove(panel_list,pd);
 	g_free(pd);
-
+	
 	return FALSE;
 }
 
@@ -932,7 +936,6 @@ bind_panel_events(GtkWidget *widget, gpointer data)
 }
 
 
-
 static void
 panel_widget_setup(PanelWidget *panel)
 {
@@ -969,7 +972,6 @@ panel_setup(GtkWidget *panelw)
 	else if(IS_CORNER_WIDGET(panelw))
 		pd->type = CORNER_PANEL;
 	else {
-		puts("panel_setup");
 		g_warning("unknown panel type");
 	}
 	
@@ -1065,10 +1067,8 @@ panel_setup(GtkWidget *panelw)
 		
 		/*this is a base panel*/
 		base_panels++;
-	} else {
-		puts("panel_setup later");
+	} else
 		g_warning("unknown panel type");
-	}
 	gtk_signal_connect(GTK_OBJECT(panelw),
 			   "event",
 			   GTK_SIGNAL_FUNC(panel_event),
