@@ -33,7 +33,11 @@ GlobalConfig global_config = {
 		DEFAULT_MINIMIZED_SIZE,
 		DEFAULT_MINIMIZE_DELAY,
 		TRUE, /*tooltips*/
-		TRUE /*show small icons*/
+		TRUE, /*show small icons*/
+		TRUE, /*logout question*/
+		PANEL_SWITCH_MOVE,
+		FALSE, /*disable anims*/
+		3 /*applet padding*/
 	};
 
 char *panel_cfg_path=NULL;
@@ -73,7 +77,8 @@ apply_global_config(void)
 				   global_config.minimized_size,
 				   global_config.minimize_delay,
 				   global_config.movement_type,
-				   global_config.disable_animations);
+				   global_config.disable_animations,
+				   global_config.applet_padding);
 	if(global_config.tooltips_enabled)
 		gtk_tooltips_enable(panel_tooltips);
 	else
@@ -311,10 +316,8 @@ save_panel_configuration(gpointer data, gpointer user_data)
 	case DRAWER_PANEL:
 		{
 		DrawerWidget *drawer = DRAWER_WIDGET(pd->panel);
-		gnome_config_set_int("orient",panel->orient);
+		gnome_config_set_int("orient",drawer->orient);
 		gnome_config_set_int("state", drawer->state);
-		gnome_config_set_int("drop_zone_pos",
-				     drawer->drop_zone_pos);
 		break;
 		}
 	default:
@@ -422,6 +425,8 @@ do_session_save(GnomeClient *client,
 				      global_config.prompt_for_logout);
 		gnome_config_set_bool("disable_animations",
 				      global_config.disable_animations);
+		gnome_config_set_int("applet_padding",
+				     global_config.applet_padding);
 	}
 
 	gnome_config_pop_prefix ();
@@ -588,9 +593,9 @@ panel_quit(void)
 static void
 load_default_applets(void)
 {
-	load_menu_applet(NULL,0, 0,panels->data);
-	load_extern_applet("gen_util_applet","--clock",
-			   INT_MAX/2/*right flush*/,panels->data,NULL);
+	load_menu_applet(NULL,0, panels->data, 0);
+	load_extern_applet("gen_util_applet","--clock",NULL,
+			   panels->data,INT_MAX/2/*right flush*/);
 	/*we laoded default applets, so we didn't find the config or
 	  something else was wrong, so do complete save when next syncing*/
 	need_complete_save = TRUE;
@@ -649,34 +654,34 @@ init_user_applets(void)
 			  when it loads*/
 			g_snprintf(buf,256,"%sApplet_%d_Extern/",
 				   old_panel_cfg_path,num);
-			load_extern_applet(path,params,pos,panel,buf);
+			load_extern_applet(path,params,buf,panel,pos);
 			g_free(path);
 			g_free(params);
 		} else if(strcmp(applet_name,LAUNCHER_ID) == 0) { 
 			char *params = gnome_config_get_string("parameters=");
-			load_launcher_applet(params,pos,panel);
+			load_launcher_applet(params,panel,pos);
 			g_free(params);
 		} else if(strcmp(applet_name,LOGOUT_ID) == 0) { 
-			load_logout_applet(pos,panel);
+			load_logout_applet(panel,pos);
 		} else if(strcmp(applet_name,SWALLOW_ID) == 0) {
 			char *path = gnome_config_get_string("execpath=");
 			char *params = gnome_config_get_string("parameters=");
 			int width = gnome_config_get_int("width=0");
 			int height = gnome_config_get_int("height=0");
-			load_swallow_applet(path,params,width,height,pos,panel);
+			load_swallow_applet(path,params,width,height,panel,pos);
 			g_free(path);
 			g_free(params);
 		} else if(strcmp(applet_name,MENU_ID) == 0) {
 			char *params = gnome_config_get_string("parameters=");
 			int main_menu_type =
 				gnome_config_get_int("main_menu_type=0");
-			load_menu_applet(params,main_menu_type,pos,panel);
+			load_menu_applet(params,main_menu_type,panel,pos);
 			g_free(params);
 		} else if(strcmp(applet_name,DRAWER_ID) == 0) {
 			char *params = gnome_config_get_string("parameters=");
 			char *pixmap = gnome_config_get_string("pixmap=");
 			char *tooltip = gnome_config_get_string("tooltip=");
-			load_drawer_applet(params,pixmap,tooltip,pos,panel);
+			load_drawer_applet(params,pixmap,tooltip,panel,pos);
 			g_free(params);
 			g_free(pixmap);
 			g_free(tooltip);
@@ -774,23 +779,16 @@ init_user_panels(void)
 		case DRAWER_PANEL:
 			{
 				DrawerState state;
-				PanelOrientation orient;
-				DrawerDropZonePos drop_pos;
+				PanelOrientType orient;
 
 				g_snprintf(buf,256,"state=%d", DRAWER_SHOWN);
 				state=gnome_config_get_int(buf);
 
-				g_snprintf(buf,256,"orient=%d", PANEL_HORIZONTAL);
+				g_snprintf(buf,256,"orient=%d", ORIENT_UP);
 				orient=gnome_config_get_int(buf);
 
-				g_snprintf(buf,256,
-					   "drop_zone_pos=%d",
-					   DROP_ZONE_LEFT);
-				drop_pos=gnome_config_get_int(buf);
-
 				panel = drawer_widget_new(orient,
 							  state,
-							  drop_pos,
 							  back_type,
 							  back_pixmap,
 							  fit_pixmap_bg,
@@ -880,6 +878,8 @@ load_up_globals(void)
 		
 	g_snprintf(buf,256,"movement_type=%d", PANEL_SWITCH_MOVE);
 	global_config.movement_type=gnome_config_get_int(buf);
+
+	global_config.applet_padding=gnome_config_get_int("applet_padding=3");
 		
 	gnome_config_pop_prefix();
 
